import React, { Component } from 'react';
import Sidebar from './Sidebar';
import { api } from '../api'
import BibliographyPage from './BibliographyPage';
import Pagination from './Pagination';
import { Link,Redirect, withRouter } from 'react-router-dom';
import { SearchBoxWithSuggestion } from '../components/SearchBoxWithSuggestion'
import Breadcrumb from 'react-bootstrap/Breadcrumb'

class Bibliography extends Component {
  state = {
    bibliographyHierarchy: [],
    sidebarData: true,
    detailData: true,
    bibliographyData: [],
    currentPage: 1,
    postsPerPage: 10,
    elementName: '',
    searchKeyword: '',
    searchKeywordGroup: '',
    heading: '',
   
  }



  // For componentDidMount
  componentDidMount() {
    const path = this.props.location.pathname
   // console.log(path ,"pathname")
    let currentPath = path.substring(path.lastIndexOf('/') + 1)
    //console.log(currentPath, 'sdsadsadsad')
    this.fetchBibliographyHier(currentPath ,path)
  }
  
  fetchBibliographySearchElement = (entity,searchKeyword, searchKeywordGroup) => {
    console.log(entity,"currentPath")
    fetch(`${api.bibliographySearch}?type=${entity}&group=${searchKeywordGroup}&keyword=${searchKeyword}`)
      .then(response => {
        if (!response || !response.ok) throw Error(response.status);
        return response.json()
      })
      .then(({ data }) => {
       // console.log(data, 'bibliography search result data', searchKeyword)
        let refineData = data.data.map((e) => {
          let arr = e.split(' ')
          let arr2 = arr.map((el) => {
            // console.log(el, 'Check 1')
            // let removeExtraChar = el.match(/p/i)
            // console.log(removeExtraChar)

            return el.replace(new RegExp(`\\b${searchKeyword}\\b`, 'gi'), `<mark class='text-capitalize'>${searchKeyword}</mark>`)


          })

          // console.log(arr2, 'CHECK 2')
          return arr2.join(' ')
        })

       // console.log(refineData, 'CHECK 3')

        this.setState({ bibliographyData: refineData, searchKeyword, searchKeywordGroup },
          () => localStorage.removeItem('bibliographySearchIteam'))
          const  type = JSON.parse(localStorage.getItem("type"));
          if (type!=entity){
            localStorage.removeItem('type')
          }
          

      })
      .catch(err => console.log('could not fetch bibliography search element data', err))
  }


  fetchBibliographyHier = (entity) => {
    fetch(`${api.biblographyHier}?type=${entity}`)
      .then(response => {
        if (!response || !response.ok) throw Error(response.status);
        return response.json()
      })
      .then((data) => {
      //  console.log(data.hier_level[0]['list_ele'][0].name, 'bibliography hier')
        this.setState({
          bibliographyHierarchy: data['hier_level'],
          elementName: data.hier_level[0]['list_ele'][0].id
        }, () => {
           
          
          const {  searchKeyword, searchKeywordGroup } = { ...JSON.parse(localStorage.getItem('bibliographySearchIteam')) }
          localStorage.setItem("type", JSON.stringify(entity));
          //console.log(this.state.bibliographyHierarchy)
        //console.log(this.state.elementName)
          searchKeyword ?
            this.fetchBibliographySearchElement(entity,searchKeyword, searchKeywordGroup) :
            this.fetchBibliographyData(entity)

        })
      })
      .catch(err => console.log('could not fetch bibliography hierarchy', err))
  }


  fetchBibliographyData = (currentpath) => {
    //  TO DO 
    let ele = ['medicine', 'environmental_sciences', 'geology_geography'].includes(currentpath) ? currentpath : this.state.elementName
    ele = ele === 'political sciences' ? 'political_sciences' : ele

    fetch(`${api.biblographydata}?type=${currentpath}&element=${ele}`)
      .then(response => {
        if (!response || !response.ok) throw Error(response.status);
        return response.json()
      })
      .then(({ data }) => {
       // console.log(data, 'bibliography data')
        var Heading = this.state.elementName
        var Heading = Heading.replace(/[#_]/g,' ');
        this.setState({ bibliographyData: data.element_data,
        heading: Heading })

      })
      .catch(err => console.log('could not fetch bibliography data', err))
  }

  getElementData = (name, currentPath) => {
    // let name1 = name === 'political sciences' ? 'political_science' : name
    this.setState({ elementName: name, searchKeywordGroup: '', searchKeyword: '' }, () => this.fetchBibliographyData(currentPath))

  }


  render() {

    const pageName= this.props.match.params.type
    const pagename= pageName.charAt(0).toUpperCase().concat(pageName.slice(1) )
    const pgname=pagename.replace(/_/g ," ")




    // re-route if group not exists
    const path = this.props.location.pathname
    let currentLocation = path.substring(path.lastIndexOf('/') + 1)
   // console.log(currentLocation, 'culjas;ld')
    // if (!['biodiversity'].includes(currentLocation)) return <Redirect to='/ladakh/not_found' />
    
    // get current posts
    const { bibliographyData, currentPage, postsPerPage, searchKeyword, searchKeywordGroup } = this.state;

    const indexOfLastPost = currentPage * postsPerPage;
    const indexOfFirstPost = indexOfLastPost - postsPerPage;
    const currentPosts = bibliographyData;

    // change page
    const paginate = (pageNumber) => this.setState({ currentPage: pageNumber });
    return (
      <section >
      <nav style={{marginTop:16 , paddingLeft:20}} aria-label="breadcrumb">
  <ol className="breadcrumb">
    <li className="breadcrumb-item"><Link to="/ladakh">Home</Link></li>
    <li className="breadcrumb-item"><Link to="/ladakh/bibliography">Bibliography</Link></li>
    <li className="breadcrumb-item active" aria-current="page">{`${pgname}`}</li>
   </ol>
    </nav>
      <main className='bioliography' >
   
        {this.state.bibliographyHierarchy.length ? <Sidebar
          list={this.state.bibliographyHierarchy}
          hasFunction
          getElementData={this.getElementData}
          currentPath={currentLocation} /> : ''}
        <div className='bioliography__body'>
          {this.props.forSearchResult ? 'Searched Result' :
            <>
              {searchKeyword ?
                <>
                  <h1 className='bioliography__heading'>Search results: {searchKeyword}</h1>
                  <h3 className='bioliography__heading' style={{ marginTop: '2rem' }}>{searchKeywordGroup}</h3>


                </> :
                <h1 className='bioliography__heading'>{this.state.heading}</h1>
              }

              <BibliographyPage data={currentPosts} />
          

            </>}

        </div>
      </main>
    </section>
    )
  }
}

export default withRouter(Bibliography)