import React, { Component } from 'react';
import { adjustOverFlows } from '../helper.js'
import Modal from '../components/Modal';
import feedback_img from '../assets/feedback.svg';
import { withRouter } from "react-router-dom";
import { api } from '../api'
import { successOptions } from '../toastConfig';
import { toast } from 'react-toastify';




class Footer extends Component {

	state = {
		toggleModal: false,
		email: "",
		feedbackData: "",
		visitorCount: 0,
		downloadCount: 0

	}



	componentDidMount() {
		//console.log(this.props.location, 'footer')
		this.getDownloadCountFromApi()
		this.getVisitorfromApi()

	}

	getVisitorfromApi = () => {
		fetch(`${api.visitorCount}/?type=visitor`)
			.then(response => {
				if (!response || !response.ok) throw Error(response.status);
				return response.json()
			})
			.then(({ data }) => {
			//	console.log(data, 'visitor data')
				this.setState({ visitorCount: data })


			})
			.catch(err => console.log('could not fetch visitor data', err))
	}



	getDownloadCountFromApi = () => {
	//	console.log('download count api calling')
		fetch(`${api.downloadPdfCount}`)
			.then(response => {
				if (!response || !response.ok) throw Error(response.status);
				return response.json()
			})
			.then(({ data }) => {
			//	console.log(data, 'download pdf count')
				this.setState({ downloadCount: data })

			})
			.catch(err => console.log('could not fetch web app download count', err))
	}

	setModalToggle = () => {

		this.setState({ email: "", feedbackData: "", toggleModal: !this.state.toggleModal },
			() => {
				window.scrollTo(0, 0);
				adjustOverFlows(this.state.toggleModal)
			})
	}

	submitFeedback = (e) => {
		e.preventDefault();

		let path = this.props.location.pathname
		// get group name from the window location path
		let elementName = path.substring(path.lastIndexOf('/') + 1)
		//console.log(elementName, 'group_name')
		// find %20 exists in elementName and remove it
		elementName = elementName.includes('%20') ? elementName.replace("%20", " ") : elementName


		fetch(`${api.feedback}`, {
			method: 'POST',
			headers: {
				'Accept': 'application/json',
				'Content-Type': 'application/json',
			},
			body: JSON.stringify({
				email: this.state.email,
				feedback: this.state.feedbackData,
				page_name: elementName

			})
		})
			.then(response => {
				if (!response || !response.ok) {
					this.setState({ toggleModal: !this.state.toggleModal },
						() => adjustOverFlows(this.state.toggleModal))
					throw Error(response.status)

				}
				return response.json();
			})
			.then(() => {
				//console.log('msg passed')
				this.setState({ email: "", feedbackData: "", toggleModal: !this.state.toggleModal },
					() => adjustOverFlows(this.state.toggleModal))
				toast.success("Your Feedback is successfully registered", successOptions);
			})
			.catch(err => console.log('Error Loggin in', err));
	}


	render() {
		return (
			<>
				<div className='footer'>
					<div className='specie__row'>
						<div className='specie__column'>
							<h2 className='footer__text'>About </h2>
							<h3 className='footer__text-value'>About Ladakh</h3>
							<h3 className='footer__text-value'>Frequently Asked Questions</h3>
							<h3 className='footer__text-value' onClick={() => { this.props.history.push('/ladakh/team') }}>Team</h3>
							<h3 className='footer__text-value'>Contact Us </h3>

						</div>
						<div className='specie__column'>
							<h2 className='footer__text'>Social Media </h2>
							<h3 className='footer__text-value'>Twitter</h3>
							<h3 className='footer__text-value'>Facebook</h3>
							<h3 className='footer__text-value'>Instagram</h3>
						</div>
						<div className='specie__column'>
							<h2 onClick={this.setModalToggle} className='footer__text'>Suggestion and Feedback</h2>
						</div>
					</div>

					<div className='footer__countSec'>
						<div className='footer__countItem'>
							<h1 className='footer__count'>{this.state.visitorCount}</h1>
							<p className='footer__countLabel'>Visitors</p>
						</div>

						<div className='footer__countItem'>
							<h1 className='footer__count'>{this.props.downloadCount ? this.props.downloadCount : this.state.downloadCount}</h1>
							<p className='footer__countLabel'>Files Download</p>
						</div>
					</div>


				</div>
				<Modal show={this.state.toggleModal}
					close={this.setModalToggle}>
					<div className='footer__feedbackSec'>
						<div className='footer__feedback_quotes'>
							<p className='footer__feedback_quotesContent'>Feel free to drop us your feedback.</p>
							<img src={feedback_img} alt='feedback_img' className='footer__feedback_quotesImg' />
						</div>

						<form className="footer__feedback_form" onSubmit={this.submitFeedback} >
							<input value={this.state.email}
								className="footer__feedback_input"
								type="email"
								placeholder="Enter Email"
								id="email"
								onChange={(e) => this.setState({ email: e.target.value })}
								required />

							<textarea value={this.state.feedbackData}
								onChange={(e) => this.setState({ feedbackData: e.target.value })}
								id="feedbackData"
								className="footer__feedback_input"
								rows="9"
								placeholder="Feedback"
								required />
							<br />
							<button type='submit' className="footer__feedback_btn">Send Feedback</button>
						</form>


					</div>

				</Modal>
			</>
		)
	}
}

export default withRouter(Footer);
