import React, { Component } from 'react'
import { api } from '../api';
import SpecieBanner from './SpecieBanner';
import Breadcrumb from 'react-bootstrap/Breadcrumb';
import Loader from 'react-loader-spinner';
import CustomBreadcrumb from './CustomBreadcrumb';
import CustomBreadcrumbItem from './CustomBreadcrumbItem';


class GroupSpecie extends Component {

    constructor(props) {
        super(props)

        this.state = {
            specieCounts: {},
            specieList: [],
            bannerImage: [],
            bannerInfo: {},
            specieGroupName: '',
            groupName: '',// related to path name
            groupList: []

        }
    }


    componentDidMount() {

        let path = this.props.location.pathname
        // get group name from the window location path
      //  console.log(path.split('/'), 'path')

        let groupName = path.split('/')[3]
        //console.log(groupName, 'group_name')

        this.speciesCount(groupName);

        this.speciesList(groupName);

        this.typeList(groupName);

    }

    speciesCount = (groupName) => {
      //  console.log('group api called')
        fetch(`${api.speciesCount}?type=${groupName}`)
            .then((response) => {
                if (!response || !response.ok) throw Error(response.status);
                return response.json()
            })
            .then(({ data }) => {
           //     console.log(data, 'specie count')
                this.setState({
                    specieCounts: data.specie_count,
                    bannerImage: data.banner_images,
                    bannerInfo: data.banner_info,
                    specieGroupName: data.heading[0],
                    groupName
                }, () => console.log(this.state.taxonomyNames))

            })
            .catch((err) => console.log('could ot fetch specie count data', err))
    }


    speciesList = (groupName) => {
        fetch(`${api.speciesList}?type=${groupName}&count=yes`)
            .then((response) => {
                if (!response || !response.ok) throw Error(response.status);
                return response.json()
            })
            .then(({ data }) => {
               // console.log(data, 'specie list')
                this.setState({ specieList: data['species_list'] })

            })
            .catch((err) => console.log('could not fetch specie list data', err))
    }


    typeList = (groupName) => {

        fetch(`${api.typeData}?type=${groupName}&id=group`)
            .then((response) => {
                if (!response || !response.ok) throw Error(response.status);
                return response.json()
            })
            .then(({ data }) => {
             //   console.log(data, 'type list')
                this.setState({ groupList: data })

            })
            .catch((err) => console.log('could not fetch type list data', err))
    }





    render() {
        return (
            <div className='specieHome'>
                <SpecieBanner
                    title={this.state.bannerInfo['title']}
                    specieCounts={this.state.specieCounts}
                    bannerImage={this.state.bannerImage}
                    type={this.state.groupName} />


                <div className="specieHome__main">
                    <CustomBreadcrumb>
                        <CustomBreadcrumbItem path='/ladakh' text='Home' />
                        <CustomBreadcrumbItem path='/ladakh/biodiversity' text='Biodiversity' />
                        <CustomBreadcrumbItem path={`/ladakh/biodiversity/${this.state.groupName}`} text={this.state.specieGroupName} />
                        <CustomBreadcrumbItem active text={'Group'} />
                    </CustomBreadcrumb>

                    {this.state.groupList.length > 0 ?
                        <>

                            <h1 className='specieHome__main_title'>{`Browse All Group`}</h1>

                            <div className='specieHome__listItem'>
                                {this.state.groupList.map((elem, i) => {
                                    return (
                                        <>
                                            <h4 className='specieHome__main_specieName'
                                                onClick={() => this.props.history.push({
                                                    pathname: `/ladakh/biodiversity/${this.state.groupName}/group/family`,
                                                    nameEle: elem,
                                                    id: 'group'

                                                })} key={elem + i + i}>{elem}</h4>
                                            {/* <br /> */}
                                        </>
                                    )
                                }
                                )}
                            </div>
                        </> : <Loader
                            type="ThreeDots"
                            color="#3c6382"
                            height={100}
                            width={100}
                        />}

                </div>


            </div>



        )
    }
}

export default GroupSpecie
