import React, { Component } from 'react';
import Sidebar from './Sidebar';
import { api } from '../api'
import Carousel from 'react-bootstrap/Carousel';
import ReactToPrint from "react-to-print";
import PDF from '../assets/pdf.svg';
import Breadcrumb from 'react-bootstrap/Breadcrumb';
import { adjustOverFlows } from '../helper';
import Modal from '../components/Modal';
import closeIcon from '../assets/cancel.svg';
import CustomBreadcrumb from './CustomBreadcrumb';
import CustomBreadcrumbItem from './CustomBreadcrumbItem';




class Specie extends Component {

  state = {
    specieDetailData: {},
    toggleModal: false,
    specieAssets: [] ,
    groupType:''
  }

  // For componentDidMount
  componentDidMount() {

    const { pathname } = this.props.location

    let specieID = pathname.split("__")[1]
    this.fetchSpecieDetail(specieID)
    this.fetchSpecieAsset(specieID)

  }

  fetchSpecieDetail = (specieID) => {
    fetch(`${api.specieDetail}?id=${specieID}`)
      .then(response => {
        if (!response || !response.ok) throw Error(response.status);
        return response.json()
      })
      .then((data) => {
      //  console.log(data, 'specie detail data')
        this.setState({
          specieDetailData: data.data,
          groupType: data.data.type
        })
       // console.log(this.state.groupType)
      })
      .catch(err => console.log('could not fetch specie detail data', err))
  }

  fetchSpecieAsset = (specieID) => {
    fetch(`${api.specieAssets}?id=${specieID}`)
      .then(response => {
        if (!response || !response.ok) throw Error(response.status);
        return response.json()
      })
      .then(({ images }) => {
        //console.log(images, 'specie assets')
        this.setState({
          specieAssets: images
        })
      })
      .catch(err => console.log('could not fetch specie assets data', err))
  }


  // updateDownloadListAPi = () => {
  //   fetch(`${api.visitorCount}/?type=specie`)
  //     .then(response => {
  //       if (!response || !response.ok) throw Error(response.status);
  //       return response.json()
  //     })
  //     .then(({ data }) => {
  //       console.log(data, 'specie pdf count')

  //     })
  //     .catch(err => console.log('could not fetch specie pdf count', err))
  // }


  // generatePdf = () => {
  //   console.log('pdf')
  //   let doc = new jsPDF("p", "pt", "A1");
  //   doc.html(document.querySelector("#fullscreen"), {
  //     callback: function (pdf) {
  //       pdf.save("mypdf.pdf");

  //     }
  //   })
  // }


  onClickModalAssets = () => {
    this.setState({ toggleModal: !this.state.toggleModal },
      () => adjustOverFlows(this.state.toggleModal)
    )
  }
  onItalicData = (value) => {
    let data = value
    let strEle = data.split(' ').filter(elm => elm !== "")
    let italicWord = strEle.slice(0, 2).join(" ")
    let nonItalic = strEle.slice(2, strEle.length + 1).join(" ")
    return (<p>
      <i>{italicWord} </i>
      {nonItalic} (Geolocations)
    </p>)
  }
  onItalicIllustraionData = (value) => {
    let data = value
    let strEle = data.split(' ').filter(elm => elm !== "")
    let italicWord = strEle.slice(0, 2).join(" ")
    let nonItalic = strEle.slice(2, strEle.length + 1).join(" ")
    return (<p>
      <i>{italicWord} </i>
      {nonItalic}
    </p>)
  }

  render() {
    // tag images with hyperlink
    const { specieDetailData } = this.state
    const hyperlinkData = Object.keys(specieDetailData).length > 0 ?
      specieDetailData['specie_hyperlink']['other_sources'].map((link, i) => {
        return { hyperlink: link, img: specieDetailData['specie_hyperlink']['sources_icon_image'][i] }
      }) : []

    const path = this.props.location.pathname
    const groupName = path.split("/")[3]


    return (
      Object.keys(specieDetailData).length > 0 ?
        <>
          <div className='specie'>

            <div className='specieHome__banner'>
              <div className='specieHome__banner_captionSec individual'>
                <h1 className='specieHome__banner_captionTitle'>{specieDetailData['banner_information']['species']}</h1>
                <p className='specieHome__banner_captionInfo'>{specieDetailData['banner_information']['banner_info']}</p>
                <div className='specieHome__banner_specieCountSec'>

                  <div className='specieHome__banner_specieCount_list'>
                    <p className="specieHome__banner_specieCount_no" style={{ fontSize: '1.8rem' }}>{specieDetailData['banner_information']['family']}</p>
                    <p className="specieHome__banner_specieCount_text" style={{ fontSize: '1.5rem', marginTop: '1rem' }}>Family</p>
                  </div>

                  <div className='specieHome__banner_specieCount_list'>
                    <p className="specieHome__banner_specieCount_no" style={{ fontSize: '1.8rem' }}>{specieDetailData['banner_information']['genus']}</p>
                    <p className="specieHome__banner_specieCount_text" style={{ fontSize: '1.5rem', marginTop: '1rem' }}>Genus</p>
                  </div>



                </div>
              </div>
              <Carousel fade={true} indicators={true} controls={false}>
                {specieDetailData['banner_information']['banner_images'].map((img, i) => {
                  return <Carousel.Item interval={10000} key={i + img}>
                    <img className="specieHome__banner_img" src={img} />
                  </Carousel.Item>
                })}
              </Carousel>
            </div>


            <div className='specie__breadcrumb-pfd_Sec' >


              <CustomBreadcrumb>
                <CustomBreadcrumbItem path='/ladakh' text='Home' />
                <CustomBreadcrumbItem path='/ladakh/biodiversity' text='Biodiversity' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}`} text={specieDetailData['name']} />
                {this.state.groupType =="plant" ?
                <>
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/group`} text='Group' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/group/family`} text='Family' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/group/family/genus`} text='Genus' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/group/family/genus/species`} text='Species' />
              </>:''}
              {this.state.groupType !="plant" ?
                <>
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/family`} text='Family' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/family/genus`} text='Genus' />
                <CustomBreadcrumbItem path={`/ladakh/biodiversity/${specieDetailData['type']}/family/genus/species`} text='Species' />
              </>:''}
                <CustomBreadcrumbItem active text={specieDetailData['banner_information']['species']} />
              </CustomBreadcrumb>

              <div className='specie__download_pdfSec'>
                <p className='specie__download_title'>Download as</p>
                {/* <PdfGenrator
              id='fullscreen'
              heading={this.state.specieName}
              heading_Xaxis={'100'}
              size={[5, 0, 240, 345]}//[x,y,width,height]
            /> */}
                {/* generating pdf with using of refs */}
                <ReactToPrint
                  trigger={() => <img src={PDF} width='45' height='45' title='Print this out!' className='specie__pdfImg' alt='pdf' />}
                  content={() => this.componentRef}
                  onAfterPrint={() => this.props.updateDownloadListAPi('specie')}
                />
              </div>

            </div>

            <main className='specie__main' id='fullscreen' ref={(el) => (this.componentRef = el)} >
              <Sidebar list={specieDetailData['specie_hier']['hier_level']} />
              {/* specie content section */}
              <section className='specie__body_container'>
                {specieDetailData['specie_data'].map((ele, i) => {
                  return (
                    <>
                      <h3 key={ele.element.name + i} id={ele.element.name} className='specie__eleTitle'>{ele.element.name}</h3>
                      {['IUCN Status', 'Nativity', 'References'].includes(ele.element.name) ?

                        ele.element.data.map((data, i) => {
                          return <p key={data + i} className='specie__subEleContent'>{data}</p>

                        })
                        :
                        ele.element.data.map((subElm, i) => {
                          return (
                            <>
                              <h5 key={i + subElm.name} id={subElm.name} className='specie__subEleTitle'>{subElm.name}</h5>
                              {subElm.data.map((data, i) => {
                                // italic first to word of string in species and synonyms only
                                let strEle = data.split(' ').filter(elm => elm !== "")
                                let italicWord = strEle.slice(0, 2).join(" ")
                                let nonItalic = strEle.slice(2, strEle.length + 1).join(" ")
                                if (['Species', 'Synonyms'].includes(subElm.name)) {
                                  return (<p key={i + data} className='specie__subEleContent'>
                                    <i>{italicWord} </i>
                                    {nonItalic}
                                  </p>)

                                }
                                else return <p key={i + data} className='specie__subEleContent'>{data}</p>


                              })}
                            </>
                          )

                        })
                      }
                    </>
                  )
                })}

              </section>
              {/* Images section of specie */}
              <section className='specie__mediaSec'>
                {specieDetailData['specie_images']['image_link'].length > 0 ?
                  <div className='specie__media_imgSec'>
                    <div className='specie__media_imglist'>
                      <img src={specieDetailData['specie_images']['image_link'][0]}

                        className='specie__media_img specie__media_img--width100'
                        alt='img1'
                        onClick={() => window.open(specieDetailData['specie_images']['image_link'][0], "_blank")} />
                      {/* {specieDetailData['specie_images']['image_link'].map((img_link, i) => {
                      return <img src={img_link}

                        key={i}
                        className={`specie__media_img ${specieDetailData['specie_images']['image_link'].length === 1 && 'specie__media_img--width100'}`}
                    alt='img1'
                    onClick={() => window.open(img_link, "_blank")} />

                    })} */}
                    </div>
                    <p className='specie__media_imgTitle'>{this.onItalicIllustraionData(specieDetailData['banner_information']['species'])}</p>
                    <a href='#' className='specie__media_moreAssets' onClick={this.onClickModalAssets}>All Illustrations</a>
                  </div>
                  : ''}

                <div className={`specie__media_imgSec ${specieDetailData['specie_images']['image_link'].length > 0 && 'specie__media_imgSec--margin'}`}>
                  <div className='specie__media_imglist'>
                    <img src={specieDetailData['specie_images']['map_link'][0]}
                      style={{ width: '100%' }}
                      alt='img3'
                      className='specie__media_img'
                      onClick={() => window.open(specieDetailData['specie_images']['map_link'][0], "_blank")} />
                  </div>

                  <p className='specie__media_imgTitle'>{
                    this.onItalicData(specieDetailData['banner_information']['species'])
                  }</p>


                </div>
              </section>


            </main>

            {/* specie hyperlink section */}
            <div className='specie__hyperlinkSec'>
              <p className='specie__hyperlink_heading'>Other Sources</p>

              <div className='specie__hyperlink_lists' >

                {hyperlinkData && hyperlinkData.map((ele, i) => {
                  return (
                    <div className="specie__hyperlink_list" key={i + ele}>
                      <img
                        src={ele['img']}
                        className='specie__hyperlink_img' alt="img"
                        onClick={() => window.open(ele['hyperlink'], "_blank")} />
                    </div>
                  )
                })}


              </div>
            </div>

          </div>


          <Modal show={this.state.toggleModal} close={this.onClickModalAssets}
            addStyle={{
              padding: '1rem'
            }}
          >
            <div className='specie__modal_header'>
              <p className='specie__modal_title'>Multimedia</p>
              <img
                src={closeIcon}
                alt='Close'
                // type='image/svg+xml' 
                // data={closeIcon}
                className='newModal__closeIcon'
                onClick={this.onClickModalAssets}
              />
            </div>

            <div className='specie__modal_imgWrapper'>


              {this.state.specieAssets.map((img, i) => {
                return (
                  <img key={i} src={img} alt={img} className='specie__modal_img' title='click to open'
                    onClick={() => window.open(img, "_blank")} />
                )
              })}
            </div>
          </Modal>

        </>

        : ''



    )
  }
}

export default Specie;
